pub struct Arguments { /* private fields */ }Implementations
Sourceimpl Arguments
main struct that organizes argument parsing
impl Arguments
main struct that organizes argument parsing
Sourcepub fn invoke_callback<F>(&mut self, flag: &str, func: F)
pub fn invoke_callback<F>(&mut self, flag: &str, func: F)
adds a callback for a flag when it is found
pub fn get_flag_index(&self, flag_name: &str) -> Option<usize>
Sourcepub fn get_arg(&self, flag_name: &str) -> Option<Arg>
pub fn get_arg(&self, flag_name: &str) -> Option<Arg>
this allows a callback to get a specific argument or flag
Sourcepub fn has_arg(&self, flag_name: &str) -> bool
pub fn has_arg(&self, flag_name: &str) -> bool
checks if a flag exists at the same level as a registered operation
pub fn get_flags(&self) -> Vec<Arg>